@@ -1,5 +1,5 @@
 --
---  $Id: sioc_ab.sql,v 1.33.2.4 2010/02/10 22:17:03 source Exp $
+--  $Id: sioc_ab.sql,v 1.33.2.6 2010/05/18 10:40:38 source Exp $
 --
 --  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
 --  project.
@@ -128,8 +128,8 @@ create procedure fill_ods_addressbook_sioc2 (
       deadl := deadl - 1;
       goto l0;
     };
-  l0:
 
+  l0:
     for (select WAI_ID,
                 WAI_IS_PUBLIC,
                 WAI_NAME,
@@ -261,40 +261,6 @@ create procedure fill_ods_addressbook_sioc2 (
       }
     }
     commit work;
-
-		id := -1;
-		deadl := 3;
-		cnt := 0;
-    declare exit handler for sqlstate '40001'
-    {
-			if (deadl <= 0)
-				resignal;
-			rollback work;
-			deadl := deadl - 1;
-			goto l1;
-		};
-	l1:
-		for (select WAI_ID,
-                WAI_IS_PUBLIC,
-								WAI_NAME
-					 from DB.DBA.WA_INSTANCE
-					where ((WAI_IS_PUBLIC = 1 and _wai_name is null) or WAI_NAME = _wai_name)
-					  and WAI_TYPE_NAME = 'AddressBook'
-					order by WAI_ID) do
-		{
-      addressbook_iri := SIOC..addressbook_iri (WAI_NAME);
-      graph_iri := SIOC..get_graph_new (null, coalesce (_access_mode, WAI_IS_PUBLIC), addressbook_iri);
-      iri := sprintf ('http://%s%s/services/addressbook', get_cname(), get_base_path ());
-      ods_sioc_service (graph_iri, iri, addressbook_iri, null, 'text/xml', iri||'/services.wsdl', iri, 'SOAP');
-
-			cnt := cnt + 1;
-	    if (mod (cnt, 500) = 0)
-	    {
-				commit work;
-				id := WAI_ID;
-			}
-    }
-		commit work;
   }
 }
 ;
@@ -358,6 +324,22 @@ create procedure clean_ods_addressbook_sioc2 (
 }
 ;
 
+-------------------------------------------------------------------------------
+--
+create procedure ods_addressbook_services (
+  in graph_iri varchar, 
+  in forum_iri varchar,
+  in wai_id varchar := null,
+  in wai_name varchar := null)
+{
+  declare svc_iri varchar;
+  
+  -- dbg_obj_print (now (), 'ods_addressbook_services');
+  svc_iri := sprintf ('http://%s%s/services/addressbook', get_cname(), get_base_path ());
+  ods_sioc_service (graph_iri, svc_iri, forum_iri, null, 'text/xml', svc_iri||'/services.wsdl', svc_iri, 'SOAP');
+}
+;
+
 -------------------------------------------------------------------------------
 --
 create procedure contact_insert (
@@ -489,7 +471,7 @@ create procedure contact_insert (
   	  {
   	    if (length (relationship))
   	    {
-  	      DB.DBA.ODS_QUAD_URI (graph_iri, iri, relationship, person_iri);
+  	      DB.DBA.ODS_QUAD_URI (graph_iri, iri, ODS.ODS_API."ontology.denormalize"(relationship), person_iri);
   	    }
   	  }
     }
