@@ -1,5 +1,5 @@
 /*
- *  $Id: bookmark.js,v 1.27.2.4 2010/02/10 22:17:03 source Exp $
+ *  $Id: bookmark.js,v 1.27.2.6 2010/07/09 14:37:00 source Exp $
  *
  *  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
  *  project.
@@ -20,6 +20,13 @@
  *  51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  *
  */
+function myA(obj) {
+  if (obj.href) {
+    document.location = obj.href + '?' + urlParam('sid') + urlParam('realm');
+    return false;
+  }
+}
+
 function myPost(frm_name, fld_name, fld_value)
 {
   createHidden(frm_name, fld_name, fld_value);
@@ -690,11 +697,10 @@ function openIFrame (id, accountID, uri)
 
 function urlParam (fldName)
 {
-  var S = '';
   var O = document.forms[0].elements[fldName];
-  if (O)
-    S += '&' + fldName + '=' + encodeURIComponent(O.value);
-  return S;
+  if (O && O.value != '')
+    return '&' + fldName + '=' + encodeURIComponent(O.value);
+  return '';
 }
 
 function showObject(id)
@@ -985,10 +991,8 @@ BMK.readField = function (field, doc)
   {
     v = doc.forms[0].elements[field];
     if (v)
-    {
       v = v.value;
     }
-  }
   return v;
 }
 
@@ -1011,8 +1015,12 @@ BMK.initState = function (state)
   if (!state)
     var state = new Object();
 
-  state.sid = BMK.readField('sid');
-  state.realm = BMK.readField('realm');
+  var v = BMK.readField('sid');
+  if (v)
+    state.sid = v;
+  var v = BMK.readField('realm');
+  if (v)
+    state.sid = v;
   if (!state.tab)
     state.tab = 'tree';
 
@@ -1250,7 +1258,7 @@ BMK.loadPath = function (w, wIndex)
     node.toggleSelect({ctrlKey:false});
   }
   BMK.selectedPath();
-  BMK.nodeAction();
+  BMK.execNodeAction();
 }
 
 BMK.findPath = function (path)
@@ -1308,7 +1316,7 @@ BMK.loadTreeData = function(nodePath, node, nodeFunction)
   OAT.AJAX.GET(S, '', x);
 }
 
-BMK.nodeAction = function()
+BMK.execNodeAction = function()
 {
   var a = $('nodeAction');
   if (a && (a.value != ''))
@@ -1569,7 +1577,7 @@ BMK.aboutDialog = function ()
   if (aboutDiv) {OAT.Dom.unlink(aboutDiv);}
   aboutDiv = OAT.Dom.create('div', {width:'430px', height:'150px'});
   aboutDiv.id = 'aboutDiv';
-  aboutDialog = new OAT.Dialog('About ODS Booomarks', aboutDiv, {width:430, buttons: 0, resize:0, modal:1});
+  aboutDialog = new OAT.Dialog('About ODS Booomarks', aboutDiv, {width:445, buttons: 0, resize:0, modal:1});
 	aboutDialog.cancel = aboutDialog.hide;
 
   var x = function (txt) {
