@@ -1,5 +1,5 @@
 /*
- *  $Id: odrive.js,v 1.15.2.11 2010/02/25 16:11:39 source Exp $
+ *  $Id: odrive.js,v 1.15.2.12 2010/07/09 14:37:01 source Exp $
  *
  *  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
  *  project.
@@ -20,6 +20,21 @@
  *  51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  *
  */
+function urlParam(fldName)
+{
+  var O = document.forms[0].elements[fldName];
+  if (O && O.value != '')
+    return '&' + fldName + '=' + encodeURIComponent(O.value);
+  return '';
+}
+
+function myA(obj) {
+  if (obj.href) {
+    document.location = obj.href + '?' + urlParam('sid') + urlParam('realm');
+    return false;
+  }
+}
+
 function myPost(frm_name, fld_name, fld_value)
 {
   createHidden(frm_name, fld_name, fld_value);
@@ -1465,7 +1480,7 @@ ODRIVE.aboutDialog = function ()
   if (aboutDiv) {OAT.Dom.unlink(aboutDiv);}
   aboutDiv = OAT.Dom.create('div', {width:'430px', height:'150px'});
   aboutDiv.id = 'aboutDiv';
-  aboutDialog = new OAT.Dialog('About ODS Briefcase', aboutDiv, {width:430, buttons: 0, resize:0, modal:1});
+  aboutDialog = new OAT.Dialog('About ODS Briefcase', aboutDiv, {width:445, buttons: 0, resize:0, modal:1});
 	aboutDialog.cancel = aboutDialog.hide;
 
   var x = function (txt) {
