@@ -1,5 +1,5 @@
 --
---  $Id: sioc_calendar.sql,v 1.19.2.3 2010/02/10 22:17:03 source Exp $
+--  $Id: sioc_calendar.sql,v 1.19.2.4 2010/05/18 10:41:26 source Exp $
 --
 --  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
 --  project.
@@ -268,6 +268,22 @@ create procedure fill_ods_calendar_sioc (
 }
 ;
 
+-------------------------------------------------------------------------------
+--
+create procedure ods_calendar_services (
+  in graph_iri varchar, 
+  in forum_iri varchar,
+  in wai_id varchar := null,
+  in wai_name varchar := null)
+{
+  declare svc_iri varchar;
+  
+  -- dbg_obj_print (now (), 'ods_calendar_services');
+  svc_iri := sprintf ('http://%s%s/%U/calendar/%U/atom-pub', get_cname(), get_base_path (), CAL.WA.domain_owner_name (wai_id), wai_name);
+  ods_sioc_service (graph_iri, svc_iri, forum_iri, null, null, null, svc_iri, 'Atom');
+}
+;
+
 -------------------------------------------------------------------------------
 --
 create procedure event_insert (
