@@ -1,5 +1,5 @@
 /*
- *  $Id: common.js,v 1.13.2.25 2010/03/29 09:06:50 source Exp $
+ *  $Id: common.js,v 1.13.2.29 2010/07/06 23:09:10 source Exp $
  *
  *  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
  *  project.
@@ -556,19 +556,11 @@ var setServiceUrl = function(fld)
     {
       if (fld.value == serviceList[N][2])
       {
-        var urlName = fld.input.name.replace(/fld_1_/, 'fld_2_');
-        $(urlName).value = serviceList[N][1]+$v('c_nick');
-      }
-    }
-	}
-
-var setServiceUrl2 = function(fld)
-  {
-    for (N = 0; N < serviceList.length; N = N + 1)
-    {
-      if (fld.value == serviceList[N][2])
-      {
-        var urlName = fld.name.replace(/fld_1_/, 'fld_2_');
+        var urlName;
+        if (fld.input)
+          urlName = fld.input.name.replace(/fld_1_/, 'fld_2_');
+        else
+          urlName = fld.name.replace(/fld_1_/, 'fld_2_');
         $(urlName).value = serviceList[N][1]+$v('c_nick');
       }
     }
@@ -673,6 +665,7 @@ RDF.ontologies['dataview'] = {"name": 'http://www.w3.org/2003/g/data-view#', "hi
 RDF.ontologies['dc'] = {"name": 'http://purl.org/dc/elements/1.1/', "hidden": 1};
 RDF.ontologies['dcterms'] = {"name": 'http://purl.org/dc/terms/', "hidden": 1};
 RDF.ontologies['foaf'] = {"name": 'http://xmlns.com/foaf/0.1/'};
+RDF.ontologies['frbr'] = {"name": 'http://vocab.org/frbr/core#'};
 RDF.ontologies['geo'] = {"name": 'http://www.w3.org/2003/01/geo/wgs84_pos#'};
 RDF.ontologies['gr'] = {"name": 'http://purl.org/goodrelations/v1#'};
 RDF.ontologies['ibis'] = {"name": 'http://purl.org/ibis#', "hidden": 1};
@@ -864,8 +857,8 @@ RDF.loadClassProperties = function(ontologyClass, cbFunction)
     cbFunction();
     return;
   }
-  var ontologyName = this.getOntologyByClass(ontologyClass.name).name;
-  var prefix = this.ontologyPrefix(ontologyName);
+  var ontologyName = RDF.getOntologyByClass(ontologyClass.name).name;
+  var prefix = RDF.ontologyPrefix(ontologyName);
   var S = '/ods/api/ontology.classProperties?ontologyClass='+encodeURIComponent(ontologyClass.name)+'&ontology='+encodeURIComponent(ontologyName)+'&prefix='+prefix;
   var x = function(data) {
     var o = null;
@@ -1401,7 +1394,7 @@ RDF.showPropertiesTable = function(item)
       var prefixProp = prefix + '_prop_' + No;
 
       var fld = OAT.Dom.create('span');
-      fld.onclick = function(){TBL.createRow(prefixProp, null, {fld_1: {mode: 46, item: item}, fld_2: {mode: 47, item: item}});};
+      fld.onclick = function(){TBL.createRow(prefixProp, null, {fld_1: {mode: 46, item: item}, fld_2: {mode: 48, item: item}, fld_3: {mode: 47, item: item}});};
       OAT.Dom.addClass(fld, 'button pointer');
 
       var img = OAT.Dom.create('img');
@@ -1415,14 +1408,14 @@ RDF.showPropertiesTable = function(item)
       TDs[2].style.whiteSpace = 'nowrap';
       TDs[2].appendChild(fld);
 
-      var S = '<table id="prop_tbl" class="listing" style="background-color: #FFF;"><thead><tr class="listing_header_row"><th width="50%">Property</th><th width="50%">Value</th><th width="80px">Action</th></tr></thead><tbody id="prop_tbody"><tr id="prop_tr_no"><td colspan="3">No Properties</td></tr></tbody></table><input type="hidden" id="prop_no" name="prop_no" value="0" />';
+      var S = '<table id="prop_tbl" class="listing" style="background-color: #FFF;"><thead><tr class="listing_header_row"><th width="50%">Property IRI</th><th width="50%" colspan="2">Value</th><th width="80px">Action</th></tr></thead><tbody id="prop_tbody"><tr id="prop_tr_no"><td colspan="3">No Properties</td></tr></tbody></table><input type="hidden" id="prop_no" name="prop_no" value="0" />';
       TDs[1].innerHTML = S.replace(/prop_/g, prefixProp+'_');
 
       var properties = item.properties;
       if (properties)
       {
         for (var i = 0; i < properties.length; i++)
-          TBL.createRow(prefixProp, null, {fld_1: {mode: 46, item: item, value: properties[i]}, fld_2: {mode: 47, item: item, value: properties[i]}});
+          TBL.createRow(prefixProp, null, {fld_1: {mode: 46, item: item, value: properties[i]}, fld_2: {mode: 48, item: item, value: properties[i]}, fld_3: {mode: 47, item: item, value: properties[i]}});
       } else {
         fld.onclick();
       }
@@ -1438,5 +1431,7 @@ RDF.changePropertyValue = function(obj)
   var fldName = S.replace(/fld_1/, 'fld_2');
   var S = obj.parentNode.id;
   var td = $(S.substr(0,S.lastIndexOf('_')+1)+'2');
+  TBL.createCell48(td, '', fldName, 0, {item: obj.item, value: {name: obj.value}});
+  var td = $(S.substr(0,S.lastIndexOf('_')+1)+'3');
   TBL.createCell47(td, '', fldName, 0, {item: obj.item, value: {name: obj.value}});
 }
