@@ -1,5 +1,5 @@
 /*
- *  $Id: tbl.js,v 1.2.2.8 2010/03/29 09:06:50 source Exp $
+ *  $Id: tbl.js,v 1.2.2.11 2010/07/06 23:09:10 source Exp $
  *
  *  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
  *  project.
@@ -178,10 +178,11 @@ TBL.createCellSelect = function (fldName) {
 TBL.createCellCombolist = function (td, fldValue, fldOptions) {
   var fld = new OAT.Combolist([], fldValue, fldOptions);
   fld.input.id = fld.input.name;
+  fld.input.style.width = "85%";
   td.appendChild(fld.div);
 
   var dims = OAT.Dom.getWH(td);
-	fld.list.style.width = (dims[0]*0.75)+"px";
+  fld.list.style.width = (((dims[0]>250)?dims[0]:250)*0.75)+"px";
 
   return fld;
 }
@@ -223,7 +224,6 @@ TBL.createCell1 = function (td, prefix, fldName, No, fldOptions) {
 
 TBL.createCell2 = function (td, prefix, fldName, No, fldOptions) {
   var fld = TBL.createCellCombolist(td, fldOptions.value, {name: fldName});
-  fld.input.style.width = "85%";
   fld.addOption('rdfs:seeAlso');
   fld.addOption('foaf:made');
   fld.addOption('foaf:maker');
@@ -234,12 +234,11 @@ TBL.createCell2 = function (td, prefix, fldName, No, fldOptions) {
 TBL.createCell10 = function (td, prefix, fldName, No, fldOptions) {
   var fld = TBL.createCellCombolist(td, fldOptions.value, {name: fldName, onchange: setServiceUrl});
   fld.input.setAttribute("autocomplete", "off");
-  fld.input.style.width = "85%";
   for (N = 0; N < serviceList.length; N = N + 1)
     fld.addOption('<img src="/ods/images/services/'+serviceList[N][0]+'"/> '+serviceList[N][2], serviceList[N][2]);
 
 	var ta = new TypeAhead(fld.input.id, 'onlineAccounts', '');
-	fld.input.onchange = setServiceUrl2;
+	fld.input.onchange = setServiceUrl;
 	fld.input.form.onsubmit = CheckSubmit;
 	taVars[taVars.length] = ta;
 
@@ -259,7 +258,6 @@ TBL.createCell11 = function (td, prefix, fldName, No, fldOptions) {
 TBL.createCell20 = function (td, prefix, fldName, No, fldOptions) {
   var fld = TBL.createCellCombolist(td, fldOptions.value, {name: fldName});
 
-	fld.input.style.width = "85%";
 	fld.addOption('rel:acquaintanceOf');
 	fld.addOption('rel:ambivalentOf');
 	fld.addOption('rel:ancestorOf');
@@ -486,7 +484,6 @@ TBL.createCell47 = function (td, prefix, fldName, No, fldOptions) {
       value = property.value;
     }
     var fld = TBL.createCellCombolist(td, value, {name: fldName});
-    fld.input.style.width = "85%";
     fld.input.combolist = fld;
     var classNames = ontologyClassProperty.objectProperties;
     for (var n = 0; n < RDF.itemTypes.length; n++) {
@@ -528,12 +525,38 @@ TBL.createCell47 = function (td, prefix, fldName, No, fldOptions) {
   }
   var fld = OAT.Dom.create('input');
   fld.type = 'hidden';
-  fld.id = fldName.replace(/fld_2/, 'fld_3');
+  fld.id = fldName.replace('fld_3', 'fld_2');
   fld.name = fld.id;
   fld.value = propertyType;
   td.appendChild(fld);
 }
 
+TBL.createCell48 = function (td, prefix, fldName, No, fldOptions) {
+  if (!td) {return;}
+
+  td.style.width = '1%';
+  // clear
+  td.innerHTML = '';
+
+  // get product
+  var item = fldOptions.item;
+  if (!item) {return;}
+
+  // get property
+  var property = fldOptions.value;
+  if (!property) {return;}
+
+  // get property data
+  var propertyType;
+  var ontologyClassProperty = RDF.getOntologyClassProperty(item.className, property.name);
+  if (ontologyClassProperty && ontologyClassProperty.objectProperties) {
+    td.innerHTML = 'URI';
+  }
+  else if (ontologyClassProperty && ontologyClassProperty.datatypeProperties) {
+    td.innerHTML = 'Literal';
+  }
+}
+
 TBL.createButton0 = function (td, prefix, fldName, No, fldOptions)
 {
   var fld = OAT.Dom.create('span');
