@@ -1,7 +1,7 @@
 --
 --  url_rev.sql
 --
---  $Id: url_rew.sql,v 1.35.2.1 2009/10/06 10:20:04 source Exp $
+--  $Id: url_rew.sql,v 1.35.2.4 2010/07/09 14:36:48 source Exp $
 --
 --  URL rewrite rules for ODS
 --
@@ -66,11 +66,17 @@ create procedure DB.DBA.ODS_DISC_ITEM_ID (in par varchar, in fmt varchar, in val
 create procedure DB.DBA.ODS_ITEM_PAGE (in par varchar, in fmt varchar, in val varchar)
 {
   declare ret any;
-  if (par = 'inst')
+  if ((par = 'inst') or (par = 'inst2'))
     {
-      if (length (val))
-        val := split_and_decode (val)[0];
-      ret := (select WAM_HOME_PAGE from WA_MEMBER where WAM_INST = val and WAM_MEMBER_TYPE = 1);
+      ret := DB.DBA.ODS_INST_HOME_PAGE (par, fmt, val);
+      if (length (ret) and (par = 'inst2'))
+        {
+          declare pos integer;
+
+          pos := strrchr (ret, '/');
+          if (not isnull (pos))
+            ret := subseq (ret, 0, pos);
+        }
     }
   else -- item
     {
@@ -350,6 +356,15 @@ DB.DBA.URLREWRITE_CREATE_REGEX_RULE ('ods_discussion_html', 1,
     NULL,
     2);
 
+-- A rule returning home page for a given item within instance all of these having a form of <home>?id=<item id>
+DB.DBA.URLREWRITE_CREATE_REGEX_RULE ('ods_apps_page', 1,
+    '/dataspace/([^/]*)/(addressbook|bookmark|briefcase|calendar|subscriptions|polls|mail)/([^/]*)/([^/\\.\?]*)(.vspx|.vsp)',
+    vector('uname', 'app', 'inst2', 'page', 'ext'), 4,
+    '%s/%s%s', vector('inst2', 'page', 'ext'),
+    'DB.DBA.ODS_ITEM_PAGE',
+    NULL,
+    2);
+
 -- A rule returning home page for a given item within instance all of these having a form of <home>?id=<item id>
 DB.DBA.URLREWRITE_CREATE_REGEX_RULE ('ods_item_html', 1,
     '/dataspace/([^/]*)/(weblog|addressbook|ecrm|bookmark|briefcase|community|subscriptions|polls|mail|eCRM|IM)/([^/]*)/((?!gems)(?!tag)[^/\\?]*)',
@@ -512,32 +527,89 @@ create procedure DB.DBA.ODS_RDF_URI_LOC (in id int, in variant varchar)
 ;
 
 delete from DB.DBA.HTTP_VARIANT_MAP where VM_RULELIST = 'ods_rule_list1';
-DB.DBA.HTTP_VARIANT_ADD ('ods_rule_list1', 'iid \\(([0-9]*)\\)\x24', 'iid (\x241).rdf', 'application/rdf+xml', 0.95,
+DB.DBA.HTTP_VARIANT_ADD ('ods_rule_list1', 'iid%20%28([0-9]*)%29\x24', 'iid%20%28\x241%29.rdf', 'application/rdf+xml', 0.95,
     location_hook=>'DB.DBA.ODS_RDF_URI_LOC');
-DB.DBA.HTTP_VARIANT_ADD ('ods_rule_list1', 'iid \\(([0-9]*)\\)\x24', 'iid (\x241).n3', 'text/rdf+n3', 0.80,
+DB.DBA.HTTP_VARIANT_ADD ('ods_rule_list1', 'iid%20%28([0-9]*)%29\x24', 'iid%20%28\x241%29.n3', 'text/rdf+n3', 0.80,
     location_hook=>'DB.DBA.ODS_RDF_URI_LOC');
-DB.DBA.HTTP_VARIANT_ADD ('ods_rule_list1', 'iid \\(([0-9]*)\\)\x24', 'iid (\x241).turtle', 'text/turtle', 0.70,
+DB.DBA.HTTP_VARIANT_ADD ('ods_rule_list1', 'iid%20%28([0-9]*)%29\x24', 'iid%20%28\x241%29.nt', 'text/n3', 0.80,
     location_hook=>'DB.DBA.ODS_RDF_URI_LOC');
-DB.DBA.HTTP_VARIANT_ADD ('ods_rule_list1', 'iid \\(([0-9]*)\\)\x24', 'iid (\x241).ttl', 'text/rdf+ttl', 0.70,
+DB.DBA.HTTP_VARIANT_ADD ('ods_rule_list1', 'iid%20%28([0-9]*)%29\x24', 'iid%20%28\x241%29.turtle', 'text/turtle', 0.70,
     location_hook=>'DB.DBA.ODS_RDF_URI_LOC');
+DB.DBA.HTTP_VARIANT_ADD ('ods_rule_list1', 'iid%20%28([0-9]*)%29\x24', 'iid%20%28\x241%29.ttl', 'text/rdf+ttl', 0.70,
+    location_hook=>'DB.DBA.ODS_RDF_URI_LOC');
+--DB.DBA.HTTP_VARIANT_ADD ('ods_rule_list1', 'iid%20%28([0-9]*)%29\x24', 'iid%20%28\x241%29.txt', 'text/plain', 0.65,
+--    location_hook=>'DB.DBA.ODS_RDF_URI_LOC');
+DB.DBA.HTTP_VARIANT_ADD ('ods_rule_list1', 'iid%20%28([0-9]*)%29\x24', 'iid%20%28\x241%29.json', 'application/json', 0.80,
+    location_hook=>'DB.DBA.ODS_RDF_URI_LOC');
+
+create procedure DB.DBA.ODS_URLREW_HDR (in in_path varchar)
+{
+  declare host, lines, exts any;
+  declare links, tmp, path varchar;
+
+  lines := http_request_header ();
+  host := http_request_header (lines, 'Host', null, '');
+  links := '';
+--  dbg_obj_print_vars (in_path);
+  exts := 
+  vector (
+      	vector ('rdf',  'RDF/XML', 'application/rdf+xml'), 
+      	vector ('nt',   'N3/Turtle', 'text/n3'), 
+      	vector ('n3',   'N3/Turtle', 'text/rdf+n3'), 
+	vector ('json', 'RDF/JSON', 'application/json')
+	);
+  path := regexp_replace (in_path, '/(about|foaf|sioc)\\.([a-z0-9]+)\x24', '', 1, null);	
+  if (regexp_match ('/dataspace/(person|organization)/([^/]+)\x24', path) is not null)
+    {
+      tmp := path || '#this';
+    }
+  else
+    {
+      tmp := path;
+    }
+  links := 'Link: ';
+  links := links || sprintf ('<http://%s%s>; rel="http://xmlns.com/foaf/0.1/primaryTopic",', host, tmp);
+  links := links || sprintf ('\r\n <http://%s%s>; rev="describedby",', host, tmp);
+  tmp := regexp_replace (in_path, '\\.([a-z0-9]+)\x24', '', 1, null);	
+  if (tmp = in_path)
+    {
+      if (regexp_match ('/dataspace/(person|organization)/([^/]+)', path) is not null)
+	tmp := tmp || '/about';
+      else
+        tmp := tmp || '/sioc';	
+    }
+  foreach (any ss in exts) do
+    {
+      if (in_path not like '%.'||ss[0])
+	{
+	  links := links || sprintf ('\r\n <http://%s%s.%s>; rel="alternate";\r\n type="%s"; title="Structured Descriptor Document (%s format)",', 
+	  host, tmp, ss[0], ss[2], ss[1]);
+	}
+    }
+  links := rtrim (links, ',');
+  return links;
+}
+;
 
 -- RDF data rules - these was returning 303
 DB.DBA.URLREWRITE_CREATE_REGEX_RULE ('ods_rdf', 1,
     '/dataspace/([^\\?]*)', vector('path'), 1,
     '/ods/data/rdf/%U', vector('path'),
     'DB.DBA.ODS_DET_REF',
-    '(application/rdf.xml)|(text/rdf.n3)|(text/rdf.turtle)|(text/rdf.ttl)|([a-z]+/turtle)|(application/x-turtle)',
+    '(application/rdf.xml)|(text/rdf.n3)|(text/rdf.turtle)|(text/rdf.ttl)|([a-z]+/turtle)|(application/x-turtle)|(text/n3)|(application/json)',
     2,
-    null);
+    null,
+    '^{sql:DB.DBA.ODS_URLREW_HDR}^');
 
 -- RDF data rule
 DB.DBA.URLREWRITE_CREATE_REGEX_RULE ('ods_rdf_next', 1,
     '/dataspace/(.*)/page/([0-9]*)', vector('path', 'page'), 1,
     '/ods/data/rdf/%U.%U?page=%U', vector('path', '*accept*', 'page'),
     'DB.DBA.ODS_DET_REF',
-    '(application/rdf.xml)|(text/rdf.n3)|(text/rdf.turtle)|(text/rdf.ttl)|([a-z]+/turtle)|(application/x-turtle)',
+    '(application/rdf.xml)|(text/rdf.n3)|(text/rdf.turtle)|(text/rdf.ttl)|([a-z]+/turtle)|(application/x-turtle)|(text/n3)|(application/json)',
     2,
-    null);
+    null,
+    '^{sql:DB.DBA.ODS_URLREW_HDR}^');
 
 -- Rule for about, sioc, foaf etc. RDF resources
 DB.DBA.URLREWRITE_CREATE_REGEX_RULE ('ods_rdf_res', 1,
@@ -546,7 +618,8 @@ DB.DBA.URLREWRITE_CREATE_REGEX_RULE ('ods_rdf_res', 1,
     'DB.DBA.ODS_DET_REF',
     NULL,
     2,
-    null);
+    null,
+    '^{sql:DB.DBA.ODS_URLREW_HDR}^');
 
 -- Rule for moat
 DB.DBA.URLREWRITE_CREATE_REGEX_RULE ('ods_moat_res', 1,
@@ -592,6 +665,7 @@ DB.DBA.URLREWRITE_CREATE_RULELIST ('ods_rule_list1', 1,
 	  'ods_cal_atom_html',
 	  'ods_apps_gems_html',
 	  'ods_apps_tags_html',
+	  'ods_apps_page',
 	  'ods_discussion_item_html',
 	  'ods_blog_tag',
 	  'ods_main',
